import * as React from 'react';
import type { ModalProps } from 'antd/lib/modal/Modal';
import type { BaseButtonProps } from 'antd/lib/button/button';
import type { WrappedFormUtils, ValidationRule } from 'antd/lib/form/Form';
/**
 * 表单布局方式 simple = 1 列 （比较宽松） | common = 2 列 （常规） |  compress = 3列 （紧凑）
 * 说明，如果不传此值时，将以 输入参数的数量决定默认值 ：规则
 *  1. 小于8全字段时，默认使用  simple
 *  2. 大于8个字段时，默认使用  common
*/
export type UFormLayout = 'common' | 'simple' | 'compress';
/**
 * 分组展示的方式 default = 默认 |  tabs = 标签  | collapse = 折叠风琴
*/
export type GroupType = 'default' | 'tabs' | 'collapse';
/**
 * 联动结果 ： 改变目标字段的交互属性
 * 所有属性为可选，需要改变几项属性，则只返回包含几个属性的对象，
 * 比如     return {show:false}                         // 仅改变显示状态
 *          return  {show:false,required:false}         // 同时改变显示状态，必填状态
*/
export type LinkResult = {
    /**
     * 是否显示
    */
    show?: boolean;
    /**
     * 是否可以输入
    */
    disabled?: boolean;
    /**
     * 是否必填
    */
    required?: boolean;
    /**
     * 选项
     * 说明： 需要清空之前的选择，使用初始 options 时，请返回 `null`
     *      如 :  return { options: null}
    */
    options?: Option[];
    /**
     * 值
    */
    value?: string | number | boolean;
};
/**
 * 联动
*/
export type Link = {
    /**
     * 联动字段
    */
    field: string;
    /**
     * 联动事件
     * 返回值为  string | number | boolean 时，改变目标field 的 value
     * 返回值为  LinkResult, 类型时，根据返回结果改变目标 filed 的 显示/置灰/选项集/值的状态
     * 说明：目前暂不支持 返回 Promise 对象，如果需要发请求的联动可暂时使用 GETASNYC/POSTASYNC 同步方法
     * extra 支持扩展返回，用于非本表单的数据传递
    */
    call: (txt: string | number, obj?: any, extra?: any) => string | number | boolean | LinkResult;
};
export type Option = {
    /**
     * 选项显示在页面上的文字
    */
    name: React.ReactNode;
    /**
     * 选项选中后的值
    */
    value: string | number | boolean;
    /**
     * 子节点：
     * 说明： 目前仅用于 tree-select, cascader 输入类型
     * 说明2 :  tree-select, cascader 如果需要被联动options 时，则必须传 options ， 不要传 config:{treeData} ,否则联动不能生效
    */
    children?: Option[];
    /**
     * 自定义扩展字段
    */
    [propName: string]: any;
};
/**
 * 说明：属性配置支持三种模式
 * I = Info     = 查看详情
 * A = Add      = 添加
 * E = Edit    = 修改模式
 * 目前自动判断规则 = 通过 data 参数判断
 * 1. 传 **data** = Update ，
 * 2. 不传= Add
*/
export type APPEAR_MODE = 'I' | 'A' | 'E' | 'IA' | 'IE' | 'AE' | 'IAE' | false | true;
/**
 * 表单的字段定义
*/
export type UFormField = {
    /**
     * 列名称
    */
    title: string;
    /**
     * 列字段
    */
    field: string;
    /**
     * 输入提示
    */
    placeholder?: string;
    /**
     * 是否显示，默认显示，不显示可以设置为show:false
    */
    show?: APPEAR_MODE;
    /**
     * 是否禁用，默认不禁用，禁用可以设置为 disabled:true
    */
    disabled?: APPEAR_MODE;
    /**
     * Type 类型列表 :  http://192.168.119.213:9999/vap-doc/frontend/components/form/
     *
     * 系统内置 Type ：
     *
     * 1. 目前 vap 内置了 30 多个内置类型
     * 2. 类型在Form系组件内通用 ： UFrom / UFormModal / UInfo / UInfoModal / UModal 。
     * 3. 部分类型是需要多个字段的，用逗号隔开， 如 { type:'timerange', field:'start,end' }
     * 4. 部分类型需要 config 设定，请按规定传入 config数据 ，如 { type:'jsonarray',config:{...} }
     * 5. 如果内置的 type 满足不了需求，可以通过自定义的方式进行扩展
     *
     *
     * 自定义 Type :
     *
     * 1. 一个 type 名称只能注册一次， 建议以 功能-操作 命名type，避免冲突
     * 2. 如果是全局多模块都需要的 type ，可以在 app-portal 里面注册
     * 3. 如果只是某个业务使用的 type ， 就在 业务app项目 里面注册
     * 4. UFrom 提供了 UFormInput / UFormMultiInput / UFormTableButton 等类型用于注册，
     *      可以方便的注册为，单字段/多字段/多字段（弹出列表选择）的输入方式。
     * */
    type?: string;
    /**
     * 占用 SPAN 大小
    */
    span?: 1 | 2 | 3;
    /**
     * 字段选项，适用于 `checkbox` `radio` `switch` 等
     * 当字段类型为 `switch`时， 数组长度必须为 2, 第一个参数放正常状态，第二个参数放异常状态
    */
    options?: Option[];
    /**
     * 提示信息，仅type 为 input 时有效
     * 1. 为字文本时，提示文本
     * 2. 为对象时，提示标题，文本，提示图标可指定
     */
    tip?: React.ReactNode;
    /**
     * FormItem 的 extra 信息
     * 说明 `tip` 显示在label 旁边，以 Icon图标显示
     * extra 直接显示
    */
    extra?: React.ReactNode;
    /**
     * rule 用法： https://github.com/yiminghe/async-validator
    */
    rule?: ValidationRule[];
    /**
     * 字段联动，目前只支持 `text` `select` 类型，受影响的字段只能是具有 `options` 属性的类型
     *
    */
    link?: Link[];
    /**
     * 扩展字段说明：
     * 自定义
     */
    config?: any;
    /**
     * render
     * 回显方法
    */
    render?: (txt: any, obj?: any) => React.ReactNode;
};
export type UFormFieldGroup = {
    /**
     * 分组标题
    */
    title: string;
    /**
     * 分组里面的字段
    */
    fields: UFormField[];
};
/**
* 新版 UForm 使用 说明 :
*              https://www.yuque.com/ada87/vap/evcmoc
* 新版 UForm TYPE 说明 :
*              https://www.yuque.com/ada87/vap/upvgq8
*/
export type UFormDefine = {
    /**
     * 自定义样式
    */
    className?: string;
    /**
     * 列表
    */
    layout?: UFormLayout;
    /**
     * 字段列表
     * 字段/字段组必选其一
    */
    fields: (UFormField[]) | (UFormFieldGroup[]);
    /**
     * 分组模式时的分组方式
    */
    groupType?: GroupType;
    /**
     * 数据
    */
    data?: any;
};
export type UFromAction = BaseButtonProps & {
    /**
     * 按钮里面的文本
    */
    text: string;
    /**
     * 0.默认为 submit
     * 1. 说明当为 default 或 submit 时 必须设置 onClick 参数
     * 2. submit 点击时会触发验证，不通过不回调，default 总是回调
    */
    action?: 'submit' | 'reset' | 'button';
    /**
     * 按钮权限
    */
    roleCode?: string;
    /**
     *
    */
    onClick?: (data?: any) => void;
    /**
     * 点击前的提示
    */
    confirm?: React.ReactNode;
};
export type UFromProps = UFormDefine & {
    /**
     * 说明：
     *
     * isEdit 将会告诉表单是 (true) UPDATE/EDIT 模式， 还是 (false) ADD/NEW  模式
     * 如果不传此参数时，判断依据为 data 字段 是否有传且不为空
     *
     * 作用于字段的 show,disabled 属性
    */
    isEdit?: boolean;
    /**
     * 默认
    */
    default?: any;
    /**
     * 操作
    */
    buttons?: UFromAction[];
};
export type UInfoProps = UFormDefine & {
    /**
     * 数据 在 UInfo 中为必传项
    */
    data: any;
    /**
     * 在弹框中增加其他内容
     */
    content?: React.ReactNode;
};
export type UFromModalProps = UFromProps & ModalProps & {
    formClassName?: string;
    width?: number;
    tip?: React.ReactNode;
};
export type UInfoModalProps = UInfoProps & ModalProps & {
    infoClassName?: string;
    width?: number;
};
/**
 * UModal 自动判断说明
 * 1. 传 mode 则为 mode  【END】
 * 2. 没有传 mode 时， 如果传入了 isEdit = true 则为 EDIT  【END】
 * 3. 如果 传入了 data ,且 data不为 null ，则为 INFO 【END】
 * 4. 否则， 为 ADD 模式 【END】
*/
export type UModalProps = UFromModalProps & UInfoModalProps & {
    mode?: 'INFO' | 'EDIT' | 'ADD';
};
/**
 * 自定义组件实现时，为组件提供的参数
*/
export interface UFormInputProps {
    /**
     * 字段定义
    */
    field: UFormField;
    /**
     * 所在表单的 Form 对象
    */
    form: WrappedFormUtils;
    /**
     * 说明，必须使用 props.onChange 事件接收值的变化内容
     * 不然会有（联动） Bug
    */
    onChange: Function;
    /**
     * 是否 disabled
    */
    disabled?: boolean;
    /**
     * 当前输入框的值
    */
    value?: any;
    /**
     * 当有 options 参数传入时，表示被 link 了 option 参数，优先使用 props.options
    */
    options?: Option[];
}
export type InfoFunction = (value: any, field?: UFormField, data?: any) => React.ReactNode;
export type ComponentOptions = {
    /**
     * 独占一行
    */
    breakCol?: boolean;
    /**
     * 不显示标题
    */
    breakTitle?: boolean;
    /**
     * 全占一行且不显示 description
    */
    breakDes?: boolean;
    /**
     * INFO模式下的回显方式
    */
    show?: InfoFunction;
    /**
     * 校验规则
     */
    rule?: ValidationRule[] | ((field: UFormField) => ValidationRule[]);
};
