"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var _ = require("lodash");
var d3 = require("d3");
var NumberPoints = new Map();
var formatDecimal = function (number, limit) {
    if (limit === void 0) { limit = 2; }
    if (!NumberPoints.has(limit)) {
        NumberPoints.set(limit, d3.format(".".concat(limit, "~f")));
    }
    return parseFloat(NumberPoints.get(limit)(number));
};
var default_1 = /** @class */ (function () {
    function default_1() {
    }
    /**
     * 字符串截取，把字符串按最大长度进行截取
     * @param txt 需要截取的字符串
     * @param len 最大长度，默认为20
     * @param hasDot 超长后是否以 `...` 进行结尾，默认为 `true`
     *
    */
    default_1.formatString = function (str, len, hasDot) {
        if (len === void 0) { len = 20; }
        if (hasDot === void 0) { hasDot = true; }
        var txt = str + '';
        if (_.isEmpty(txt)) {
            return '';
        }
        var newLength = 0;
        var newStr = [];
        var chineseRegex = /[^\x00-\xff]/g;
        var singleChar = "";
        var strLength = txt.replace(chineseRegex, "**").length;
        for (var i = 0; i < strLength; i++) {
            singleChar = txt.charAt(i).toString();
            if (singleChar.match(chineseRegex) !== null) {
                newLength += 2;
            }
            else {
                newLength++;
            }
            if (newLength > len) {
                break;
            }
            newStr.push(singleChar);
        }
        if (hasDot && strLength > len) {
            newStr.push("...");
        }
        return newStr.join('');
    };
    /**
    * @param  number 一个数字
    * @return  格式化后的字符串
    * @description 将数字格式化为带中文单位,保留两位小数，支持`万`,`亿`
    ```javascript
    PageUtil.formatNumber(123); 			//123
    PageUtil.formatNumber(100000); 			//10万
    PageUtil.formatNumber(111111); 			//11.11万
    PageUtil.formatNumber(123456789); 		//1.23亿
    ```
    */
    default_1.formatChinese = function (number) {
        if (number > 100000000) {
            return formatDecimal(number / 100000000) + '亿';
        }
        else if (number > 10000) {
            return formatDecimal(number / 10000) + '万';
        }
        return number;
    };
    /**
    * @param  number 一个数字，单位为Byte(字节)
    * @return  格式化后的字符串
    * @description 格式化容量大小,保留两位小数，支持 `B`,`KB`,`MB`,`GB`,`TB`,`PB`
    ```javascript
    PageUtil.formatSize(123); 			//123MB
    PageUtil.formatSize(1024); 			//1GB
    PageUtil.formatSize(2050); 			//2.01GB
    ```
    */
    default_1.formatSize = function (byteSize) {
        if (byteSize < 1024) {
            return formatDecimal(byteSize) + 'b';
        }
        var kbSize = (byteSize / 1024);
        if (kbSize < 1024) {
            return formatDecimal(kbSize) + 'KB';
        }
        var mbSize = (kbSize / 1024);
        if (mbSize < 1024) {
            return formatDecimal(mbSize) + 'MB';
        }
        var gbSize = (mbSize / 1024);
        if (gbSize < 1024) {
            return formatDecimal(gbSize) + 'GB';
        }
        var tbSize = (gbSize / 1024);
        if (tbSize < 1024) {
            return formatDecimal(tbSize) + 'TB';
        }
        var pbSize = (tbSize / 1024);
        return formatDecimal(pbSize) + 'PB';
    };
    default_1.formatDate = function (date, format) {
        if (format === void 0) { format = 'YYYY-MM-DD HH:mm:ss'; }
        if (_.isString(date)) {
            return moment(new Date(date)).format(format);
        }
        return moment(date).format(format);
    };
    /**
     * 格式化字符串，默认格式化为
     * aa***bb
     * @param value 被格式化字符串
     * @param beginNum 开始的字符数
     * @param endNum 结束的字符数
     */
    default_1.formatStarStr = function (value, beginNum, endNum) {
        var leftNum = _.isNumber(beginNum) ? beginNum : 2;
        var rightNum = _.isNumber(endNum) ? endNum : 4;
        var vLen = value.length;
        var rNum = vLen - rightNum < 0 ? vLen : vLen - rightNum;
        return value.substring(0, leftNum) + '***' + value.substring(rNum, vLen);
    };
    /**
        * @param number 一个数字
        * @return 格式化后的字符串
        * @description 格式化为美国数字显示方式（三位分开）
        ```javascript
        Format.formatUSD(123); 			//123
        Format.formatUSD(1234); 			//1,234
        Format.formatUSD(12345); 			//12,345
        Format.formatUSD(123456); 		//123,456
        Format.formatUSD(1234567); 		//1,234,567
        Format.formatUSD(1234567890); 	//1,234,567,890
    ```
        */
    default_1.formatUSD = d3.format(',');
    /**
    * @param number 一个数字
    * @return 格式化后的字符串
    * @description 格式化后保留两位小数
    ```javascript
    Format.formatDecimal(1.234); 			//1.23
    Format.formatDecimal(1.236); 			//1,24
    Format.formatDecimal(1.2); 			//1.2
    Format.formatDecimal(1); 				//1
    ```
    */
    default_1.formatDecimal = formatDecimal;
    default_1.formatNumber = function (number) { return formatDecimal(number, 0); };
    return default_1;
}());
exports.default = default_1;
